/*
 * errno.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef errno_h
#define errno_h


#ifndef ASM_FILE


#include<lib.h>
#include<sys/errno.h>


#ifdef DEBUG
#define PRINT_ERR(message) printError(message,__FILE__,__LINE__)
#else
#define PRINT_ERR(message) 
#endif


extern void printError(const char *,const char *,int);


#endif


#endif
